Utilities — Version 0.11.0.dev0

# Utilities

The `imblearn.utils` module includes various utilities.

## Validation checks used in samplers

`estimator_checks.parametrize_with_checks`(...) | Pytest specific decorator for parametrizing estimator checks.
`check_neighbors_object`(nn_name, nn_object[, ...]) | Check the objects is consistent to be a k nearest neighbors.
`check_sampling_strategy`(sampling_strategy, ...) | Sampling target validation for samplers.
`check_target_type`(y[, indicate_one_vs_all]) | Check the target types to be conform to the current samplers.

## Testing compatibility of your own sampler

Utils to check the samplers and compatibility with scikit-learn

`parametrize_with_checks`(estimators) | Pytest specific decorator for parametrizing estimator checks.

previous

fetch_datasets

next

parametrize_with_checks